@@ -1,4 +1,4 @@
-'''
+"""
 NMEA Protocol handler - handles all incoming standard and proprietary NMEA sentences
 
 Uses pynmea2 library for parsing
@@ -6,7 +6,7 @@ Uses pynmea2 library for parsing
 Created on 30 Sep 2020
 
 @author: semuadmin
-'''
+"""
 
 # pylint: disable=invalid-name
 from time import time
@@ -14,19 +14,28 @@ from datetime import datetime
 from pynmea2 import parse as nmea_parse, ParseError, types, RMC, VTG, GSV, GGA, GSA, GLL
 from pynmea2.types.proprietary.ubx import UBX00
 
-from .globals import DEVICE_ACCURACY, HDOP_RATIO, SAT_EXPIRY, knots2ms, kmph2ms, nmea2latlon
+from .globals import (
+    DEVICE_ACCURACY,
+    HDOP_RATIO,
+    SAT_EXPIRY,
+    knots2ms,
+    kmph2ms,
+    nmea2latlon,
+)
 from .strings import NMEAVALERROR
 
 
-class NMEAHandler():
-    '''
+class NMEAHandler:
+    """
     NMEAHandler class
-    '''
+    """
 
     def __init__(self, app):
-        '''
+        """
         Constructor.
-        '''
+
+        :param app: reference to main tkinter application
+        """
 
         self.__app = app  # Reference to main application class
         self.__master = self.__app.get_master()  # Reference to root class (Tk)
@@ -34,7 +43,9 @@ class NMEAHandler():
         self._raw_data = None
         self._parsed_data = None
         self._record_track = False
-        self.gsv_data = []  # Holds array of current satellites in view from NMEA GSV sentences
+        self.gsv_data = (
+            []
+        )  # Holds array of current satellites in view from NMEA GSV sentences
         self.gsv_log = {}  # Holds cumulative log of all satellites seen
         self.lon = 0
         self.lat = 0
@@ -46,14 +57,16 @@ class NMEAHandler():
         self.vdop = 0
         self.hacc = 0
         self.vacc = 0
-        self.utc = ''
+        self.utc = ""
         self.sip = 0
-        self.fix = '-'
+        self.fix = "-"
 
     def process_data(self, data: bytes):
-        '''
+        """
         Process NMEA message type
-        '''
+
+        :param data: bytes
+        """
 
         try:
             parsed_data = nmea_parse(data)
@@ -72,7 +85,9 @@ class NMEAHandler():
             self._process_GGA(parsed_data)
         if isinstance(parsed_data, GLL):  # GLL Lat Lon Data
             self._process_GLL(parsed_data)
-        if isinstance(parsed_data, GSA):  # GPS DOP (Dilution of Precision) and active satellites
+        if isinstance(
+            parsed_data, GSA
+        ):  # GPS DOP (Dilution of Precision) and active satellites
             self._process_GSA(parsed_data)
         if isinstance(parsed_data, VTG):  # GPS Vector track and Speed over the Ground
             self._process_VTG(parsed_data)
@@ -83,129 +98,162 @@ class NMEAHandler():
 
         return self._parsed_data
 
-    def _update_console(self, raw_data, parsed_data):
-        '''
+    def _update_console(self, raw_data: bytes, parsed_data: types.talker):
+        """
         Write the incoming data to the console in raw or parsed format.
-        '''
 
-        if self.__app.frm_settings.get_settings()['raw']:
+        :param: raw_data: bytes
+        :param: parsed_data: pynmea2.types.talker
+        """
+
+        if self.__app.frm_settings.get_settings()["raw"]:
             self.__app.frm_console.update_console(repr(raw_data))
         else:
             self.__app.frm_console.update_console(repr(parsed_data))
 
     def _process_RMC(self, data: types.talker):
-        '''
+        """
         Process RMC sentence - Recommended minimum data for GPS.
-        '''
+
+        :param: data: pynmea2.types.talker
+        """
 
         try:
             self.utc = data.timestamp
             (self.lat, self.lon) = nmea2latlon(data)
-            if data.spd_over_grnd != 'None':
+            if data.spd_over_grnd != "None":
                 self.speed = knots2ms(data.spd_over_grnd)  # convert to m/s
             self.track = data.true_course
-            self.__app.frm_banner.update_banner(time=self.utc, lat=self.lat,
-                                                lon=self.lon, speed=self.speed,
-                                                track=self.track)
-            if self.__app.frm_settings.get_settings()['webmap']:
-                self.__app.frm_mapview.update_map(lat=self.lat, lon=self.lon, static=False)
-            else:
-                self.__app.frm_mapview.update_map(lat=self.lat, lon=self.lon, static=True)
+            self.__app.frm_banner.update_banner(
+                time=self.utc,
+                lat=self.lat,
+                lon=self.lon,
+                speed=self.speed,
+                track=self.track,
+            )
+
+            self.__app.frm_mapview.update_map(self.lat, self.lon, self.hacc)
+
         except ValueError as err:
             self.__app.set_status(NMEAVALERROR.format(err), "red")
 
     def _process_GGA(self, data: types.talker):
-        '''
+        """
         Process GGA sentence - GPS Fix Data.
-        '''
+
+        :param: data: pynmea2.types.talker
+        """
 
         try:
             self.utc = data.timestamp
             self.sip = data.num_sats
             (self.lat, self.lon) = nmea2latlon(data)
             self.alt = data.altitude
-            self.__app.frm_banner.update_banner(time=self.utc, lat=self.lat,
-                                                lon=self.lon, alt=self.alt, sip=self.sip)
-            if self.__app.frm_settings.get_settings()['webmap']:
-                self.__app.frm_mapview.update_map(lat=self.lat, lon=self.lon, static=False)
-            else:
-                self.__app.frm_mapview.update_map(lat=self.lat, lon=self.lon, static=True)
+            self.__app.frm_banner.update_banner(
+                time=self.utc, lat=self.lat, lon=self.lon, alt=self.alt, sip=self.sip
+            )
 
-            if self.__app.frm_settings.get_settings()['recordtrack'] \
-                and self.lat != '' and self.lon != '':
+            self.__app.frm_mapview.update_map(self.lat, self.lon, self.hacc)
+
+            if (
+                self.__app.frm_settings.get_settings()["recordtrack"]
+                and self.lat != ""
+                and self.lon != ""
+            ):
                 time = self.ts2utc(data.timestamp)
-                ele = 0 if self.alt == 'None' else self.alt
-                self.__app.file_handler.add_trackpoint(self.lat, self.lon, ele=ele,
-                                                   time=time, sat=self.sip)
+                ele = 0 if self.alt == "None" else self.alt
+                self.__app.file_handler.add_trackpoint(
+                    self.lat, self.lon, ele=ele, time=time, sat=self.sip
+                )
         except ValueError as err:
             self.__app.set_status(NMEAVALERROR.format(err), "red")
 
     def _process_GLL(self, data: types.talker):
-        '''
+        """
         Process GLL sentence - GPS Lat Lon.
-        '''
+
+        :param: data: pynmea2.types.talker
+        """
 
         try:
             self.utc = data.timestamp
             (self.lat, self.lon) = nmea2latlon(data)
-            self.__app.frm_banner.update_banner(time=self.utc, lat=self.lat, lon=self.lon)
-            if self.__app.frm_settings.get_settings()['webmap']:
-                self.__app.frm_mapview.update_map(lat=self.lat, lon=self.lon, static=False)
-            else:
-                self.__app.frm_mapview.update_map(lat=self.lat, lon=self.lon, static=True)
+            self.__app.frm_banner.update_banner(
+                time=self.utc, lat=self.lat, lon=self.lon
+            )
+
+            self.__app.frm_mapview.update_map(self.lat, self.lon, self.hacc)
+
         except ValueError as err:
             self.__app.set_status(NMEAVALERROR.format(err), "red")
 
     def _process_GSA(self, data: types.talker):
-        '''
+        """
         Process GSA sentence - GPS DOP (Dilution of Precision) and active satellites.
-        '''
+
+        :param: data: pynmea2.types.talker
+        """
 
         self.pdop = float(data.pdop)
         self.hdop = float(data.hdop)
         self.vdop = float(data.vdop)
-        if data.mode_fix_type == '3':
-            fix = '3D'
-        elif data.mode_fix_type == '2':
-            fix = '2D'
+        if data.mode_fix_type == "3":
+            fix = "3D"
+        elif data.mode_fix_type == "2":
+            fix = "2D"
         else:
-            fix = 'NO FIX'
+            fix = "NO FIX"
 
-        if self.__app.frm_settings.get_settings()['webmap']:
-            self.__app.frm_mapview.update_map(lat=self.lat, lon=self.lon, hacc=self.hacc,
-                                              vacc=self.vacc, fix=fix, static=False)
-        else:
-            self.__app.frm_mapview.update_map(lat=self.lat, lon=self.lon, hacc=self.hacc,
-                                              vacc=self.vacc, fix=fix, static=True)
+        self.__app.frm_mapview.update_map(self.lat, self.lon, self.hacc)
 
-        self.__app.frm_banner.update_banner(dop=self.pdop, hdop=self.hdop, vdop=self.vdop, fix=fix)
+        self.__app.frm_banner.update_banner(
+            dop=self.pdop, hdop=self.hdop, vdop=self.vdop, fix=fix
+        )
 
     def _process_GSV(self, data: types.talker):
-        '''
+        """
         Process GSV sentences - GPS Satellites in View
         These come in batches of 1-4 sentences, each containing the positions
         of up to 4 satellites (16 satellites in total).
         Modern receivers can send multiple batches corresponding to different
         NMEA assigned 'ID' ranges (GPS 1-32, SBAS 33-64, GLONASS 65-96)
-        '''
+
+        :param: data: pynmea2.types.talker
+        """
 
         self.gsv_data = []
         gsv_dict = {}
         now = time()
 
         try:
-            if data.sv_prn_num_1 != '':
-                gsv_dict[data.sv_prn_num_1] = (data.elevation_deg_1,
-                                               data.azimuth_1, data.snr_1, now)
-            if data.sv_prn_num_2 != '':
-                gsv_dict[data.sv_prn_num_2] = (data.elevation_deg_2,
-                                               data.azimuth_2, data.snr_2, now)
-            if data.sv_prn_num_3 != '':
-                gsv_dict[data.sv_prn_num_3] = (data.elevation_deg_3,
-                                               data.azimuth_3, data.snr_3, now)
-            if data.sv_prn_num_4 != '':
-                gsv_dict[data.sv_prn_num_4] = (data.elevation_deg_4,
-                                               data.azimuth_4, data.snr_4, now)
+            if data.sv_prn_num_1 != "":
+                gsv_dict[data.sv_prn_num_1] = (
+                    data.elevation_deg_1,
+                    data.azimuth_1,
+                    data.snr_1,
+                    now,
+                )
+            if data.sv_prn_num_2 != "":
+                gsv_dict[data.sv_prn_num_2] = (
+                    data.elevation_deg_2,
+                    data.azimuth_2,
+                    data.snr_2,
+                    now,
+                )
+            if data.sv_prn_num_3 != "":
+                gsv_dict[data.sv_prn_num_3] = (
+                    data.elevation_deg_3,
+                    data.azimuth_3,
+                    data.snr_3,
+                    now,
+                )
+            if data.sv_prn_num_4 != "":
+                gsv_dict[data.sv_prn_num_4] = (
+                    data.elevation_deg_4,
+                    data.azimuth_4,
+                    data.snr_4,
+                    now,
+                )
         except AttributeError:
             pass
 
@@ -222,9 +270,11 @@ class NMEAHandler():
         self.__app.frm_graphview.update_graph(self.gsv_data, len(self.gsv_data))
 
     def _process_VTG(self, data: types.talker):
-        '''
+        """
         Process VTG sentence - GPS Vector track and Speed over the Ground.
-        '''
+
+        :param: data: pynmea2.types.talker
+        """
 
         try:
             self.track = data.true_track
@@ -235,20 +285,23 @@ class NMEAHandler():
             self.__app.set_status(NMEAVALERROR.format(err), "red")
 
     def _process_UBX00(self, data: types.ubx.UBX00):
-        '''
+        """
         Process UXB00 sentence - GPS Vector track and Speed over the Ground.
-        '''
+
+        :param: data: pynmea2.types.talker
+        """
 
         try:
             self.hacc = float(data.h_acc)
             self.vacc = float(data.v_acc)
             self.__app.frm_banner.update_banner(hacc=self.hacc, vacc=self.vacc)
+
         except ValueError as err:
             self.__app.set_status(NMEAVALERROR.format(err), "red")
 
     @staticmethod
-    def _estimate_acc(dop) -> float:
-        '''
+    def _estimate_acc(dop: float) -> float:
+        """
         Derive a graphic indication of positional accuracy (in m) based on the HDOP
         (Horizontal Dilution of Precision) value and the nominal native device
         accuracy (datasheet CEP)
@@ -257,16 +310,33 @@ class NMEAHandler():
         between HDOP and accuracy based solely on generic NMEA data.
         The NMEA PUBX,00 or UBX NAV-POSLLH message types return an explicit estimate
         of horizontal and vertical accuracy and are the preferred source.
-        '''
+
+        :param: dop: float horizontal dilution of precision
+
+        :return: horizontal accuracy as float:
+        """
 
         return float(dop) * DEVICE_ACCURACY * HDOP_RATIO / 1000
 
     @staticmethod
     def ts2utc(timestamp) -> str:
-        '''
+        """
         Convert NMEA timestamp to utc time
-        '''
+
+        :param: NMEA timestamp from pynmea2
+
+        :return: utc time as str:
+        """
 
         t = datetime.now()
-        s = str(t.year) + '-' + str(t.month) + '-' + str(t.day) + 'T' + str(timestamp) + 'Z'
+        s = (
+            str(t.year)
+            + "-"
+            + str(t.month)
+            + "-"
+            + str(t.day)
+            + "T"
+            + str(timestamp)
+            + "Z"
+        )
         return s
